#!/usr/bin/env python

import os
import re

from setuptools import setup, find_packages


def find_version(*segments):
    root = os.path.abspath(os.path.dirname(__file__))
    abspath = os.path.join(root, *segments)
    with open(abspath, "r") as file:
        content = file.read()
    match = re.search(r"^__version__ = ['\"]([^'\"]+)['\"]", content, re.MULTILINE)
    if match:
        return match.group(1)
    raise RuntimeError("Unable to find version string!")


setup(
    author="Richard Davis",
    author_email="crashvb@gmail.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    description="A declarative window instantiation utility based on xdotool.",
    entry_points="""
        [console_scripts]
        xdotoolp=xdotoolp.xdotoolp:cli
    """,
    extras_require={
        "dev": [
            "black",
            "pylint",
            "pytest",
            "twine",
            "wheel",
        ]
    },
    include_package_data=True,
    install_requires=["click", "pyyaml"],
    keywords="instantiation window xdotool",
    license="GNU General Public LIcense v3.0",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    name="xdotoolp",
    packages=find_packages(),
    tests_require=["pytest"],
    test_suite="tests",
    url="https://pypi.org/project/xdotoolp/",
    version=find_version("xdotoolp", "__init__.py"),
)
